@@ -32,6 +32,7 @@
 #include "idosourcemenuitem.h"
 #include "idoswitchmenuitem.h"
 #include "idoprogressmenuitem.h"
+#include "idoremovablemenuitem.h"
 
 #define IDO_TYPE_MENU_ITEM_FACTORY         (ido_menu_item_factory_get_type ())
 #define IDO_MENU_ITEM_FACTORY(o)           (G_TYPE_CHECK_INSTANCE_CAST ((o), IDO_TYPE_MENU_ITEM_FACTORY, IdoMenuItemFactory))
@@ -98,6 +99,9 @@ ido_menu_item_factory_create_menu_item (AyatanaMenuItemFactory *factory,
   else if (g_str_equal (type, "org.ayatana.indicator.switch"))
     item = ido_switch_menu_item_new_from_menu_model (menuitem, actions);
 
+  else if (g_str_equal (type, "org.ayatana.indicator.removable"))
+    item = ido_removable_menu_item_new_from_model (menuitem, actions);
+
   return item;
 }
 
